Project description
===================

Crecombio is a simple Cre, Flp and other site-specific DNA recombination simulator.


**Install:**

.. code:: bash

  pip install crecombio

**Web documentation:** `<https://edinburgh-genome-foundry.github.io/crecombio/>`_

**Github page:** `<https://github.com/Edinburgh-Genome-Foundry/crecombio>`_

**License:** MIT

Copyright 2021 Edinburgh Genome Foundry, University of Edinburgh


More biology software
---------------------

.. image:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/Edinburgh-Genome-Foundry.github.io/master/static/imgs/logos/egf-codon-horizontal.png
  :target: https://edinburgh-genome-foundry.github.io/

Crecombio is part of the `EGF Codons <https://edinburgh-genome-foundry.github.io/>`_ synthetic biology software suite for DNA design, manufacturing and validation.
